@@ -7,15 +7,15 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#include "document.h"
 
 #include <QFile>
 #include <QDataStream>
 #include <QTextCodec>
 
 #include <kencodingprober.h>
-#include <QtCore/QDebug>
+#include <QDebug>
 
-#include "document.h"
 #include "debug_txt.h"
 
 using namespace Txt;
@@ -71,4 +71,4 @@ QString Document::toUnicode( const QByteArray &array )
     return QTextCodec::codecForName( encoding )->toUnicode( array );
 }
 
-Q_LOGGING_CATEGORY(OkularTxtDebug, "org.kde.okular.generators.txt")
+Q_LOGGING_CATEGORY(OkularTxtDebug, "org.kde.okular.generators.txt", QtWarningMsg)
