@@ -14,6 +14,7 @@
 #define _OKULAR_FORMWIDGETS_H_
 
 #include "core/area.h"
+#include "core/form.h"
 
 #include <qcheckbox.h>
 #include <qcombobox.h>
@@ -60,6 +61,8 @@ class FormWidgetsController : public QObject
 
         void signalAction( Okular::Action *action );
 
+        void processScriptAction( Okular::Action *a, Okular::FormField * field, Okular::Annotation::AdditionalActionType type );
+
         void registerRadioButton( FormWidgetIface *fwButton, Okular::FormFieldButton *formButton );
         void dropRadioButtons();
         bool canUndo();
@@ -116,6 +119,14 @@ class FormWidgetsController : public QObject
 
         void action( Okular::Action *action );
 
+        void focusAction( const Okular::Action *action, Okular::FormFieldText *ff );
+
+        void formatAction( const Okular::Action *action, Okular::FormFieldText *ff );
+
+        void keystrokeAction( const Okular::Action *action, Okular::FormFieldText *ff, bool &ok );
+
+        void validateAction( const Okular::Action *action, Okular::FormFieldText *ff, bool &ok );
+
         void refreshFormWidget( Okular::FormField * form );
 
     private Q_SLOTS:
@@ -248,6 +259,7 @@ class FormLineEdit : public QLineEdit, public FormWidgetIface
     private:
         int m_prevCursorPos;
         int m_prevAnchorPos;
+        bool m_editing;
     DECLARE_ADDITIONAL_ACTIONS
 };
 
@@ -279,6 +291,7 @@ class TextAreaEdit : public KTextEdit, public FormWidgetIface
     private:
         int m_prevCursorPos;
         int m_prevAnchorPos;
+        bool m_editing;
     DECLARE_ADDITIONAL_ACTIONS
 };
 
