@@ -227,7 +227,7 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
         for ( int i = 0; i < screenCount; ++i )
         {
             QAction *act = m_screenSelect->addAction( i18nc( "%1 is the screen number (0, 1, ...)", "Screen %1", i ) );
-            act->setData( qVariantFromValue( i ) );
+            act->setData( QVariant::fromValue( i ) );
         }
     }
     QWidget *spacer = new QWidget( m_topBar );
@@ -283,6 +283,9 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
 
     // setFocus() so KCursor::setAutoHideCursor() goes into effect if it's enabled
     setFocus( Qt::OtherFocusReason );
+
+    // Catch TabletEnterProximity and TabletLeaveProximity events from the QApplication
+    qApp->installEventFilter( this );
 }
 
 PresentationWidget::~PresentationWidget()
@@ -312,6 +315,8 @@ PresentationWidget::~PresentationWidget()
 
     // delete frames
     qDeleteAll( m_frames );
+
+    qApp->removeEventFilter( this );
 }
 
 
@@ -531,6 +536,30 @@ void PresentationWidget::setPlayPauseIcon()
     }
 }
 
+bool PresentationWidget::eventFilter (QObject *o, QEvent *e )
+{
+    if ( o == qApp )
+    {
+        if ( e->type() == QTabletEvent::TabletEnterProximity )
+        {
+            setCursor( QCursor( Qt::CrossCursor ) );
+        }
+        else if ( e->type() == QTabletEvent::TabletLeaveProximity )
+        {
+            setCursor( QCursor( Okular::Settings::slidesCursor() == Okular::Settings::EnumSlidesCursor::Hidden ? Qt::BlankCursor : Qt::ArrowCursor ) );
+            if ( Okular::Settings::slidesCursor() == Okular::Settings::EnumSlidesCursor::HiddenDelay) {
+                // Trick KCursor to hide the cursor if needed by sending an "unknown" key press event
+                // Send also the key release to make the world happy even it's probably not needed
+                QKeyEvent kp( QEvent::KeyPress, 0, Qt::NoModifier );
+                qApp->sendEvent( this, &kp );
+                QKeyEvent kr( QEvent::KeyRelease, 0, Qt::NoModifier );
+                qApp->sendEvent( this, &kr );
+            }
+        }
+    }
+    return false;
+}
+
 // <widget events>
 bool PresentationWidget::event( QEvent * e )
 {
@@ -625,7 +654,7 @@ void PresentationWidget::wheelEvent( QWheelEvent * e )
         return;
 
     // performance note: don't remove the clipping
-    int div = e->delta() / 120;
+    int div = e->angleDelta().y() / 120;
     if ( div > 0 )
     {
         if ( div > 3 )
@@ -853,12 +882,9 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
     }
 
     // blit the pixmap to the screen
-    QVector<QRect> allRects = pe->region().rects();
-    uint numRects = allRects.count();
     QPainter painter( this );
-    for ( uint i = 0; i < numRects; i++ )
+    for ( const QRect &r : pe->region() )
     {
-        const QRect & r = allRects[i];
         if ( !r.isValid() )
             continue;
 #ifdef ENABLE_PROGRESS_OVERLAY
@@ -1177,11 +1203,10 @@ void PresentationWidget::generateContentsPage( int pageNum, QPainter & p )
     p.translate( -frame->geometry.left(), -frame->geometry.top() );
 
     // fill unpainted areas with background color
-    QRegion unpainted( QRect( 0, 0, m_width, m_height ) );
-    QVector<QRect> rects = unpainted.subtracted( frame->geometry ).rects();
-    for ( int i = 0; i < rects.count(); i++ )
+    const QRegion unpainted( QRect( 0, 0, m_width, m_height ) );
+    const QRegion rgn = unpainted.subtracted( frame->geometry );
+    for ( const QRect & r : rgn )
     {
-        const QRect & r = rects[i];
         p.fillRect( r, Okular::Settings::slidesBackgroundColor() );
     }
 }
@@ -1373,11 +1398,11 @@ QRect PresentationWidget::routeMouseDrawingEvent( QMouseEvent * e )
         // add drawing to current page
         m_frames[ m_frameIndex ]->drawings << m_drawingEngine->endSmoothPath();
 
-        // manually disable and re-enable the pencil mode, so we can do
-        // cleaning of the actual drawer and create a new one just after
+        // remove the actual drawer and create a new one just after
         // that - that gives continuous drawing
-        slotChangeDrawingToolEngine( QDomElement() );
-        slotChangeDrawingToolEngine( m_currentDrawingToolElement );
+        delete m_drawingEngine;
+        m_drawingRect = QRect();
+        m_drawingEngine = new SmoothPathEngine( m_currentDrawingToolElement );
 
         // schedule repaint
         update();
